<?php declare(strict_types=1);

namespace App\Http\Requests\Registry\Version2;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Registry\V2\AuthorizationService\Authorization;
use App\Dto\Service\Registry\V2\AuthorizationService\Scope;
use Illuminate\Foundation\Http\FormRequest;

final class AuthRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'service'   => ['required', 'string'],
            'scope'     => ['nullable', 'string', 'regex:/^repository\:[a-z0-9]+(?:[._-][a-z0-9]+)*\/[a-z0-9]+(?:[._-][a-z0-9]+)*\:(push,pull|pull,push|pull)$/'],
        ];
    }

    public function getDto(): Authorization
    {
        $scope = $this->input('scope', null);
        if (! \is_null($scope)) {
            $scope = Scope::parse($scope);
        }

        return new Authorization(
            service: $this->input('service'),
            scope:   $scope,
            user:    $this->user(),
        );
    }
}
