<?php declare(strict_types=1);

namespace App\Http\Requests\Registry\Version2;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Registry\V2\EventService\DataProcessing;
use App\Dto\Service\Registry\V2\EventService\Event;
use App\Dto\Service\Registry\V2\EventService\Events;
use Illuminate\Foundation\Http\FormRequest;

final class EventRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'events' => 'required|array',
            'events.*.timestamp' => 'required|string',
            'events.*.action' => 'required|string',
            'events.*.target' => 'required|array',
        ];
    }

    public function getDto(): DataProcessing
    {
        $events = new Events();

        foreach ($this->input('events', []) as $event) {
            $events->addEvent(
                new Event(
                    timestamp: $event['timestamp'] ?? '',
                    action:    $event['action'] ?? '',
                    target:    $event['target'] ?? [],
                )
            );
        }

        return new DataProcessing($events);
    }
}
