<?php declare(strict_types=1);

namespace App\Models;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;

final class TagRepository extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'tags_repository';

    /**
     * All of the relationships to be touched.
     *
     * @var array
     */
    protected $touches = ['repository'];

    /**
     * The model's default values for attributes.
     *
     * @var array
     */
    protected $attributes = [
        'quantity_pulls' => 0,
    ];

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'digest',
        'size',
    ];

    public function repository(): BelongsTo
    {
        return $this->belongsTo(Repository::class);
    }

    public function architecture(): BelongsTo
    {
        return $this->belongsTo(Architecture::class)->with('os');
    }
}
