<?php declare(strict_types=1);

namespace App\Policies;

use App\Models\Repository;
use App\Models\TagRepository;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

abstract readonly class Policy
{
    use HandlesAuthorization;

    final public function before(User $user, string $ability = '', string|object $model = ''): ?bool
    {
        if ($user->is_active !== true) {
            return false;
        }

        if (
            is_string($model) && $model === Repository::class
            || is_object($model) && $model::class === Repository::class

            || is_string($model) && $model === TagRepository::class
            || is_object($model) && $model::class === TagRepository::class
        ) {
            return null;
        }

        if ($user->is_admin && $user->currentAccessToken() === null) {
            return true;
        }

        return null;
    }
}
