<?php declare(strict_types=1);

namespace App\Services\Registry\V2;

use App\Contracts\ServiceResultError;
use App\Dto\Service\Registry\V2\AuthorizationConfig;
use App\Dto\Service\Registry\V2\AuthorizationService\Authorization;
use App\ServiceResults\ServiceResultArray;
use App\Services\Service;

final class AuthorizationService extends Service
{
    public function __construct(
        private readonly AuthorizationConfig  $authorizationConfig,
        private readonly JwtCommand           $jwtCommand,
        private readonly PayloadCommand       $payloadCommand,
        private readonly AccessCommand        $accessCommand,
    ) { }

    public function authorization(Authorization $authorization): ServiceResultArray | ServiceResultError
    {
        if ($authorization->getService() !== $this->authorizationConfig->getServiceName()) {
            return $this->errUnauthorized(__('Service name does not match'));
        }

        try {
            $access   = $this->accessCommand->execute($authorization->getScope(), $authorization->getUser());
            $username = $authorization->getUser()?->username ?? '';
            $payload  = $this->payloadCommand->execute($this->authorizationConfig, $access, $username);

            $jwt      = $this->jwtCommand->execute($this->authorizationConfig, $payload);
        } catch (\Throwable $e) {
            report($e);
            return $this->errService(__('Server Error'));
        }

        return $this->result([
            'token' => $jwt
        ]);
    }
}
